@@ -32,7 +32,9 @@ class VeriSoftReport(ParserBase):
             "Data Set B",
             "Calibrate Air Density",
             "Set Zero X",
+            "Set Zero X Units",
             "Set Zero Y",
+            "Set Zero Y Units",
             "Gamma Dist.",
             "Gamma Dose",
             "Gamma Dose Info",
@@ -43,17 +45,29 @@ class VeriSoftReport(ParserBase):
             "Gamma (Median)",
             "Gamma (Max)",
             "Gamma Min Position X",
+            "Gamma Min Position X Units",
             "Gamma Min Position Y",
+            "Gamma Min Position Y Units",
             "Gamma Max Position X",
+            "Gamma Max Position X Units",
             "Gamma Max Position Y",
+            "Gamma Max Position Y Units",
             "Abs Dose (Min)",
+            "Abs Dose (Min Units)",
             "Abs Dose (Mean)",
+            "Abs Dose (Mean Units)",
             "Abs Dose (Median)",
+            "Abs Dose (Median Units)",
             "Abs Dose (Max)",
+            "Abs Dose (Max Units)",
             "Abs Dose Min Position X",
+            "Abs Dose Min Position X Units",
             "Abs Dose Min Position Y",
+            "Abs Dose Min Position Y Units",
             "Abs Dose Max Position X",
+            "Abs Dose Max Position X Units",
             "Abs Dose Max Position Y",
+            "Abs Dose Max Position Y Units",
             "Number of Dose Points",
             "Evaluated Dose Points",
             "Evaluated Dose Points (%)",
@@ -93,6 +107,7 @@ class VeriSoftReport(ParserBase):
         keys = [
             "Administrative Data",
             "Data Set A",
+            "Manipulations",
             "Set Zero",
             "Calibrate Air Density",
             "Gamma 2D",
@@ -188,7 +203,10 @@ class VeriSoftReport(ParserBase):
         str
             Value of ``block``[``index``] of "N/A"
         """
-        return block[index] if block is not None else "N/A"
+        try:
+            return block[index].strip()
+        except Exception:
+            return "N/A"
 
     def _get_diff_position(self, key, index):
         """Used for Gamma & Abs Dose diff min and max positions
@@ -203,24 +221,33 @@ class VeriSoftReport(ParserBase):
         Returns
         -------
         dict
-            "x" and "y" positions (with units)
+            'x' and 'y' positions, 'x_units' and 'y_units'
         """
-        x, y = ["N/A", ""], ["N/A", ""]
+        x, y = ["N/A"] * 2, ["N/A"] * 2
         anchor = self.anchors[key]
         if anchor is not None:
             text_block = anchor["text"].split("\n")
             split = text_block[index].split("(")[1].replace(")", "").split(";")
             x = split[0].split("=")[1].strip().split(" ")
             y = split[1].split("=")[1].strip().split(" ")
-        return {"x": x[0] + x[1], "y": y[0] + y[1]}
+        return {"x": x[0], "x_units": x[1], "y": y[0], "y_units": y[1]}
 
     def _set_manipulations_data(self):
         """Set data from the Manipulations table"""
-        key = "Calibrate Air Density"
-        data = self.data.get_block_data(
-            self.anchors[key]["page"],
-            (self.anchors[key]["bbox"][0], self.anchors[key]["bbox"][1]),
-            tol=(1000, 10),
+        key = None
+        if self.anchors["Calibrate Air Density"]:
+            key = "Calibrate Air Density"
+        elif self.anchors["Manipulations"]:
+            key = "Manipulations"
+
+        data = (
+            self.data.get_block_data(
+                self.anchors[key]["page"],
+                (self.anchors[key]["bbox"][0], self.anchors[key]["bbox"][1]),
+                tol=(1000, 10),
+            )
+            if key is not None
+            else []
         )
         parameters, values = [], []
         for block in data:
@@ -248,7 +275,7 @@ class VeriSoftReport(ParserBase):
         str
             Institution from Administrative Data table
         """
-        return self.admin_block[0].strip()
+        return self._get_block_element(self.admin_block, 0)
 
     @property
     def physicist(self):
@@ -259,7 +286,7 @@ class VeriSoftReport(ParserBase):
         str
             Physicist from Administrative Data table
         """
-        return self.admin_block[1].strip()
+        return self._get_block_element(self.admin_block, 1)
 
     @property
     def patient_id(self):
@@ -270,7 +297,7 @@ class VeriSoftReport(ParserBase):
         str
             Patient ID from Administrative Data table
         """
-        return self.admin_block[2].strip()
+        return self._get_block_element(self.admin_block, 2)
 
     @property
     def patient_name(self):
@@ -281,7 +308,7 @@ class VeriSoftReport(ParserBase):
         str
             Patient name from Administrative Data table
         """
-        return self.admin_block[-2].strip()
+        return self._get_block_element(self.admin_block, -2)
 
     @property
     def comment(self):
@@ -292,7 +319,7 @@ class VeriSoftReport(ParserBase):
         str
             Comment from Administrative Data table
         """
-        return self.admin_block[-1].strip()
+        return self._get_block_element(self.admin_block, -1)
 
     ########################################################################
     # Dataset Block
@@ -351,26 +378,34 @@ class VeriSoftReport(ParserBase):
         return self._get_manipulation_value("kUser")
 
     @property
-    def set_zero_x(self):
-        """Get the Set Zero x value
+    def set_zero(self):
+        """Get the Set Zero data
 
         Returns
         -------
-        str
-            Get the Set Zero x from Manipulations table
+        dict
+            Get the Set Zero data from Manipulations table
         """
-        return self._get_manipulation_value("LR")
+        return {key: self._get_set_zero(key) for key in ["TG", "LR"]}
 
-    @property
-    def set_zero_y(self):
-        """Get the Set Zero y value
+    def _get_set_zero(self, key):
+        """If Set Zero is found, split by value and units
+
+        Parameters
+        ----------
+        key : str
+            Either 'LR' or 'TG'
 
         Returns
         -------
-        str
-            Get the Set Zero y from Manipulations table
+        dict
+            Keys of 'value' and 'units', each value is a strings
         """
-        return self._get_manipulation_value("TG")
+        ans = self._get_manipulation_value(key)
+        if " " in ans:
+            split = ans.split(" ")
+            return {"value": split[0].strip(), "units": split[1].strip()}
+        return {"value": "N/A", "units": "N/A"}
 
     def _get_manipulation_value(self, key):
         """Get a manipulation_data value
@@ -497,13 +532,29 @@ class VeriSoftReport(ParserBase):
         Returns
         -------
         dict
-            Mean, min, max, median Absolute Difference values
+            'mean', 'min', 'max', 'median' Absolute Difference values, and
+            'mean_units', etc
         """
-        return {
+
+        ans = {
             key: self._get_block_element(self.abs_diff_block, i)
+            .split(" ")[0]
+            .strip()
             for i, key in enumerate(["mean", "min", "max", "median"])
         }
 
+        for i, key in enumerate(["mean", "min", "max", "median"]):
+            if ans["mean"] != "N/A":
+                ans[key + "_units"] = (
+                    self._get_block_element(self.abs_diff_block, i)
+                    .split(" ")[1]
+                    .strip()
+                )
+            else:
+                ans[key + "_units"] = "N/A"
+
+        return ans
+
     @property
     def abs_diff_min_pos(self):
         """Get the min absolute dose diff position
@@ -717,6 +768,8 @@ class VeriSoftReport(ParserBase):
         abs_min_pos = self.abs_diff_min_pos
         abs_max_pos = self.abs_diff_max_pos
 
+        set_zero = self.set_zero
+
         return {
             "Patient Name": self.patient_name,
             "Patient ID": self.patient_id,
@@ -728,8 +781,10 @@ class VeriSoftReport(ParserBase):
             "Data Set A": self.data_set_a,
             "Data Set B": self.data_set_b,
             "Calibrate Air Density": self.calibrate_air_density,
-            "Set Zero X": self.set_zero_x,
-            "Set Zero Y": self.set_zero_y,
+            "Set Zero X": set_zero["LR"]["value"],
+            "Set Zero X Units": set_zero["LR"]["units"],
+            "Set Zero Y": set_zero["TG"]["value"],
+            "Set Zero Y Units": set_zero["TG"]["units"],
             "Gamma Dist.": self.gamma_dist,
             "Gamma Dose": self.gamma_dose,
             "Gamma Dose Info": self.gamma_dose_info,
@@ -740,17 +795,29 @@ class VeriSoftReport(ParserBase):
             "Gamma (Median)": gamma_diff["median"],
             "Gamma (Max)": gamma_diff["max"],
             "Gamma Min Position X": gamma_min_pos["x"],
+            "Gamma Min Position X Units": gamma_min_pos["x_units"],
             "Gamma Min Position Y": gamma_min_pos["y"],
+            "Gamma Min Position Y Units": gamma_min_pos["y_units"],
             "Gamma Max Position X": gamma_max_pos["x"],
+            "Gamma Max Position X Units": gamma_max_pos["x_units"],
             "Gamma Max Position Y": gamma_max_pos["y"],
+            "Gamma Max Position Y Units": gamma_max_pos["y_units"],
             "Abs Dose (Min)": abs_diff["min"],
+            "Abs Dose (Min Units)": abs_diff["min_units"],
             "Abs Dose (Mean)": abs_diff["mean"],
+            "Abs Dose (Mean Units)": abs_diff["mean_units"],
             "Abs Dose (Median)": abs_diff["median"],
+            "Abs Dose (Median Units)": abs_diff["median_units"],
             "Abs Dose (Max)": abs_diff["max"],
+            "Abs Dose (Max Units)": abs_diff["max_units"],
             "Abs Dose Min Position X": abs_min_pos["x"],
+            "Abs Dose Min Position X Units": abs_min_pos["x_units"],
             "Abs Dose Min Position Y": abs_min_pos["y"],
+            "Abs Dose Min Position Y Units": abs_min_pos["y_units"],
             "Abs Dose Max Position X": abs_max_pos["x"],
+            "Abs Dose Max Position X Units": abs_max_pos["x_units"],
             "Abs Dose Max Position Y": abs_max_pos["y"],
+            "Abs Dose Max Position Y Units": abs_max_pos["y_units"],
             "Number of Dose Points": self.num_dose_points,
             "Evaluated Dose Points": self.eval_dose_points,
             "Evaluated Dose Points (%)": self.eval_dose_points_percent,
