@@ -319,16 +319,17 @@ TEST_DATA = {
                 "Difference (%)": "2",
                 "Distance (mm)": "2",
                 "Threshold (%)": "10.0",
+                "Rotation Angle": "N/A",
                 "Meas Uncertainty": "No",
                 "Use Global (%)": "Yes",
-                "Summary Type": "Gamma",
+                "Dose Diff Thresh": "N/A",
+                "Use VanDyk": "N/A",
+                "Summary Type": "Summary (Gamma Analysis)",
                 "Total Points": "68",
                 "Pass": "68",
                 "Fail": "0",
                 "Pass (%)": "100",
                 "Notes": "2% 2mm TB4",
-                "Meas File": "...\\5by5 6x.txt",
-                "Plan File": "...\\Water_...",
             },
         },
         "FirstNorthwestern": {
@@ -351,16 +352,17 @@ TEST_DATA = {
                 "Difference (%)": "2.0",
                 "Distance (mm)": "2.0",
                 "Threshold (%)": "20.0",
+                "Rotation Angle": "N/A",
                 "Meas Uncertainty": "No",
                 "Use Global (%)": "No",
-                "Summary Type": "GC",
+                "Dose Diff Thresh": "N/A",
+                "Use VanDyk": "N/A",
+                "Summary Type": "Summary (GC Analysis)",
                 "Total Points": "567",
                 "Pass": "512",
                 "Fail": "55",
                 "Pass (%)": "90.3",
-                "Notes": "Notes\nbst1 \npelvis\nSLC",
-                "Meas File": "",
-                "Plan File": "",
+                "Notes": "bst1 \npelvis\nSLC",
             },
         },
         "MergedDataNorthwestern": {
@@ -383,16 +385,50 @@ TEST_DATA = {
                 "Difference (%)": "2.0",
                 "Distance (mm)": "2.0",
                 "Threshold (%)": "20.0",
+                "Rotation Angle": "N/A",
                 "Meas Uncertainty": "No",
                 "Use Global (%)": "No",
-                "Summary Type": "GC",
+                "Dose Diff Thresh": "N/A",
+                "Use VanDyk": "N/A",
+                "Summary Type": "Summary (GC Analysis)",
                 "Total Points": "2197",
                 "Pass": "1940",
                 "Fail": "257",
                 "Pass (%)": "88.3",
-                "Notes": "Notes\nFields 1-2\nPelvis=Cervix+PM+LNs\nSLF",
-                "Meas File": "",
-                "Plan File": "",
+                "Notes": "Fields 1-2\nPelvis=Cervix+PM+LNs\nSLF",
+            },
+        },
+        "UVermontHealth1": {
+            "path": join(
+                DIRECTORIES["SNCPATIENT_EXAMPLES"],
+                "UVermontHealthNetwork",
+                "ArcCheck_Example_1.pdf",
+            ),
+            "data": {
+                "Patient Name": "",
+                "Patient ID": "",
+                "QA Date": "7/9/2018",
+                "Plan Date": "7/9/2018",
+                "Energy": "10 MV",
+                "Angle": "",
+                "SSD": "",
+                "SDD": "N/A",
+                "Depth": "",
+                "Dose Type": "Absolute",
+                "Difference (%)": "2",
+                "Distance (mm)": "3.0",
+                "Threshold (%)": "10.0",
+                "Rotation Angle": "0.0 Degs",
+                "Meas Uncertainty": "Yes",
+                "Use Global (%)": "N/A",
+                "Dose Diff Thresh": "0.0 cGy",
+                "Use VanDyk": "Yes",
+                "Summary Type": "Summary (Gamma Analysis)",
+                "Total Points": "1386",
+                "Pass": "1323",
+                "Fail": "63",
+                "Pass (%)": "95.5",
+                "Notes": "19E",
             },
         },
     },
@@ -503,6 +539,10 @@ TEST_DATA = {
                 "Data Set A": "M:\\Eclipse Physics - Cancer Institute\\ABMC\\External Beam\\Point Dose QA\\RapidArc QA\\2021\\F, H\\Composite.dcm",
                 "Data Set B": "Data Set B\nAdded Data Sets:\nA.mcc\nB.mcc",
                 "Calibrate Air Density": "1.032",
+                "Set Zero X": "0.8",
+                "Set Zero X Units": "mm",
+                "Set Zero Y": "0.8",
+                "Set Zero Y Units": "mm",
                 "Gamma Dist.": "3.0mm",
                 "Gamma Dose": "3.0%",
                 "Gamma Dose Info": "Dose difference with ref. to max. dose of calculated volume",
@@ -568,6 +608,10 @@ TEST_DATA = {
                 "Data Set A": "M:\\Eclipse Physics - Cancer Institute\\ABMC\\External Beam\\Point Dose QA\\RapidArc QA\\2021\\D, M\\Composite.dcm",
                 "Data Set B": "Data Set B\nAdded Data Sets:\nA.mcc\nB.mcc",
                 "Calibrate Air Density": "1.040",
+                "Set Zero X": "N/A",
+                "Set Zero X Units": "N/A",
+                "Set Zero Y": "N/A",
+                "Set Zero Y Units": "N/A",
                 "Gamma Dist.": "3.0mm",
                 "Gamma Dose": "3.0%",
                 "Gamma Dose Info": "Dose difference with ref. to max. dose of selected slice",
@@ -633,6 +677,10 @@ TEST_DATA = {
                 "Data Set A": "M:\\Eclipse Physics - Cancer Institute\\ABMC\\External Beam\\Point Dose QA\\RapidArc QA\\2021\\C, R\\Composite.dcm",
                 "Data Set B": "Data Set B\nAdded Data Sets:\nA.mcc\nB.mcc",
                 "Calibrate Air Density": "1.039",
+                "Set Zero X": "0.3",
+                "Set Zero X Units": "mm",
+                "Set Zero Y": "1.1",
+                "Set Zero Y Units": "mm",
                 "Gamma Dist.": "3.0mm",
                 "Gamma Dose": "3.0%",
                 "Gamma Dose Info": "Dose difference with ref. to max. dose of calculated volume",
@@ -681,5 +729,74 @@ TEST_DATA = {
                 "Passing Red": "0.0%",
             },
         },
+        "ACI_NoAirCalibration": {
+            "path": join(
+                DIRECTORIES["VERISOFT_EXAMPLES"],
+                "AMITA_Health",
+                "ANON0004.pdf",
+            ),
+            "data": {
+                "Patient Name": "N/A",
+                "Patient ID": "N/A",
+                "Institution": "N/A",
+                "Physicist": "N/A",
+                "Comment": "N/A",
+                "Date": "2021-01-25 12:30:46",
+                "Version": "VeriSoft 6.2",
+                "Data Set A": "J:\\RadOnc-HIN\\Physics\\IMRT QA\\2021 IMRT QA\\Grid Test\\QA1\\PA-753 mu solid P.dcm",
+                "Data Set B": "Data Set B\nJ:\\RadOnc-HIN\\Physics\\IMRT QA\\2021 IMRT QA\\Grid Test\\QA1\\PA.xcc",
+                "Calibrate Air Density": "",
+                "Set Zero X": "-0.6",
+                "Set Zero X Units": "mm",
+                "Set Zero Y": "-0.2",
+                "Set Zero Y Units": "mm",
+                "Gamma Dist.": "3.0mm",
+                "Gamma Dose": "3.0%",
+                "Gamma Dose Info": "Dose difference with ref. to max. dose of selected slice",
+                "Threshold": "10.0%",
+                "Threshold Info": "of max. dose of selected slice",
+                "Gamma (Min)": "0.008",
+                "Gamma (Mean)": "0.421",
+                "Gamma (Median)": "0.382",
+                "Gamma (Max)": "1.157",
+                "Gamma Min Position X": "-15.0",
+                "Gamma Min Position X Units": "mm",
+                "Gamma Min Position Y": "-35.0",
+                "Gamma Min Position Y Units": "mm",
+                "Gamma Max Position X": "-10.0",
+                "Gamma Max Position X Units": "mm",
+                "Gamma Max Position Y": "-30.0",
+                "Gamma Max Position Y Units": "mm",
+                "Abs Dose (Min)": "0.114",
+                "Abs Dose (Min Units)": "cGy",
+                "Abs Dose (Mean)": "30.493",
+                "Abs Dose (Mean Units)": "cGy",
+                "Abs Dose (Median)": "29.017",
+                "Abs Dose (Median Units)": "cGy",
+                "Abs Dose (Max)": "71.911",
+                "Abs Dose (Max Units)": "cGy",
+                "Abs Dose Min Position X": "-15.0",
+                "Abs Dose Min Position X Units": "mm",
+                "Abs Dose Min Position Y": "-35.0",
+                "Abs Dose Min Position Y Units": "mm",
+                "Abs Dose Max Position X": "20.0",
+                "Abs Dose Max Position X Units": "mm",
+                "Abs Dose Max Position Y": "20.0",
+                "Abs Dose Max Position Y Units": "mm",
+                "Number of Dose Points": "1,405",
+                "Evaluated Dose Points": "520",
+                "Evaluated Dose Points (%)": "37.0%",
+                "Passed Points": "519",
+                "Passed Points (%)": "99.8%",
+                "Failed Points": "1",
+                "Failed Points (%)": "0.2%",
+                "Pass Rate": "99.8",
+                "Pass Result Color": "Green",
+                "Passing Criteria": "Gamma ≤ 1.0",
+                "Passing Green": "95.0%",
+                "Passing Yellow": "93.0%",
+                "Passing Red": "0.0%",
+            },
+        },
     },
 }
